==> kubernetes-model-policy-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/PodDisruptionBudgetSpecFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodDisruptionBudgetSpecFluent<A extends PodDisruptionBudgetSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMinAvailable();
  public IntOrString buildMinAvailable();
  public A withMinAvailable(IntOrString minAvailable);
  public Boolean hasMinAvailable();
  public A withNewMinAvailable(Object value);
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(IntOrString item);
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getSelector();
  public LabelSelector buildSelector();
  public A withSelector(LabelSelector selector);
  public Boolean hasSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
  public String getUnhealthyPodEvictionPolicy();
  public A withUnhealthyPodEvictionPolicy(String unhealthyPodEvictionPolicy);
  public Boolean hasUnhealthyPodEvictionPolicy();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface MinAvailableNested<N> extends Nested<N>,IntOrStringFluent<PodDisruptionBudgetSpecFluent.MinAvailableNested<N>>{
    public N and();
    public N endMinAvailable();
    
  }
  public interface SelectorNested<N> extends Nested<N>,LabelSelectorFluent<PodDisruptionBudgetSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> kubernetes-model-policy-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/PodDisruptionBudgetSpecFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodDisruptionBudgetSpecFluent<A extends PodDisruptionBudgetSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMinAvailable();
  public IntOrString buildMinAvailable();
  public A withMinAvailable(IntOrString minAvailable);
  public Boolean hasMinAvailable();
  public A withNewMinAvailable(Object value);
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(IntOrString item);
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable();
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getSelector();
  public LabelSelector buildSelector();
  public A withSelector(LabelSelector selector);
  public Boolean hasSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector();
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
  public String getUnhealthyPodEvictionPolicy();
  public A withUnhealthyPodEvictionPolicy(String unhealthyPodEvictionPolicy);
  public Boolean hasUnhealthyPodEvictionPolicy();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface MinAvailableNested<N> extends Nested<N>,IntOrStringFluent<PodDisruptionBudgetSpecFluent.MinAvailableNested<N>>{
    public N and();
    public N endMinAvailable();
    
  }
  public interface SelectorNested<N> extends Nested<N>,LabelSelectorFluent<PodDisruptionBudgetSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
